@@ -104,15 +104,42 @@ class TestFront(unittest.TestCase):
         The normal use case is have the caller supply all the connection information.
         """
         dsl = DSLibrary(spec={"inputs": {"db": {"uri": "mysql://host/db", "username": "u"}}})
-        def connect(user, host, database, **kwargs):
-            assert user == "u"
-            assert host == "host"
-            assert database == "db"
-            return "CONN"
         with mock.patch("pymysql.connect", connect):
             r = dsl.get_sql_connection("db")
             assert r == "CONN"
 
+    def test_load_dataframe_from_sql__flavors(self):
+        """
+        SQL has to be quoted different for different engines.
+        """
+        dsl = DSLibrary()
+        for flavor in ("postgres", "mysql"):
+            log = []
+
+            def connect(uri, **kwargs):
+                self.assertEqual(uri, 'postgresql://host/database')
+                self.assertEqual(kwargs["username"], "u")
+                class DbCursor(object):
+                    description = [("x", None)]
+                    def execute(self, sql):
+                        log.append(sql)
+                    def __iter__(self):
+                        return iter([(1,), (2,)])
+                class DbConn(object):
+                    def cursor(self):
+                        return DbCursor()
+                    def close(self):
+                        pass
+                    _flavor = flavor
+                return DbConn()
+            with mock.patch("dslibrary.front.connect_to_database", connect):
+                r = dsl.load_dataframe("postgresql://host/database", sql_table="TableName", username="u")
+                self.assertEqual(list(r.x), [1, 2])
+                if flavor == "postgres":
+                    self.assertEqual(log, ['SELECT * from "TableName"'])
+                else:
+                    self.assertEqual(log, ['SELECT * from TableName'])
+
     def test_write_resources__dataframes_and_series(self):
         """
         Several types are supported for columnar data.
